<?php
/**
 * 2018-2023 MXB Informatica.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@mxbinformatica.it so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    MXB Informatica <info@mxbinformatica.it>
 *  @copyright 2013-2023 MXB Informatica
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

/**
 * NOTICE:
 * This module was inspired to the Prestashop module "ps_banner"
 * "ps_banner" was used as a basic code.
 * Starting from its original structure, mxb_banner has some different features and supports html
 *
 * Also its structure has been upgraded to easy duplicate and customize the module. 
 * Installing 2 or more customized copies of this module, you can enable/disable it for different customers or put it into different sections of the website
 */

 /**
  * ###### DUPLICATE & CUSTOMIZE 1/3: 
  *        you are customizing "mxb_banner_one"
  *        where "one" is your [customname]
  *        if you want to create "mxb_banner_products", "products" will be your [customname]
  *        [customname] in file and folder name MUST be a string without underscores and in lowercase. YES: "bestseller" - NO: "BestSeller", "best_seller", "best-seller", "bestseller22"
  *        [Customname] in Class name MUST be capitalized. YES: "Customname", "Bestseller" ....
  *        [special extensions tpl_, js_, css_, translations/*.php_]: that files are ready to be installed with the customized name of the module. You can change it as you wish but remember to leave the "_mxb_[module]_" key untouched: it will be substituted with the right module name during the installation.
  *
  *        remember to change:
  *            the module folder name to "mxb_banner_[customname]"
  *            the module main class filename "mxb_banner_[customname].php"
  *            file "config.xml":
  *                the module name value to "mxb_banner_[customname]"
  *              file "mxb_banner_[customname].php":
  *                the class name Mxb_Banner_[Customname]
  *                the CUSTOM_NAME const value in class declaration
  */ 

/**
 * for DEBUG: if you use mxb_tools module, you'll find the log file in folder: /module/mxb_tools/log/
 *         require_once _PS_MODULE_DIR_.'mxb_tools/classes/Mxb_ToolsDebug.php';
 * and then use this function:
 *        Mxb_ToolsDebug::WriteLog($classname, $function, $message, $bypass_settings = false)
 *    i.e: 
 *        Mxb_ToolsDebug::WriteLog($this->name, 'className::__construct()', 'START', true);
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;
// require_once _PS_MODULE_DIR_.'gadgetcard/classes/LogDebug.php';

 /**
  * ###### DUPLICATE & CUSTOMIZE 2/3: class declaration: change the class name as the module name: Mxb_Customblocks_[Customname] 
  */
class Mxb_Banner_One extends Module implements WidgetInterface
{
    /**
     * ###### DUPLICATE 3/3:    set CUSTOM_NAME as "yourname" in lowercase
     *                          set $mainHook as you wish: it is the default hook for this module
     */
    const CUSTOM_NAME   = 'one';
    // 'displayNav1', 'displayNav2', 'displayWrapperTop', 'displayHome', 'displayBanner', 'displayNavFullWidth' and so on    
    // public $mainHook    = 'displayNav1';
    public $mainHook    = 'displayHome';

    /**
     * ###### DUPLICATE & CUSTOMIZE: no more changes are needed from here
     */

    const MODULE_NAME_ROOT = 'mxb_banner';
    public $documentationUrl = 'https://www.mxbinformatica.it/prestashop-mxb-banner/';
    public $thumbnailUrl = 'https://www.mxbinformatica.it/ps_modules/thumbs/mxb_banner.jpg';
    private $templateFile;

    // the following version variable is for development, used do update databases and other stuff without reinstalling the module
    // please check checkForUpdates() function
    // use int value !
    const MXB_DEV_VERSION = 2;

    public function __construct()
    {
        /**
         * ###### DUPLICATE & CUSTOMIZE: no more changes are needed from here
         */
         
        $this->customName       = self::CUSTOM_NAME;
        $this->rootName         = self::MODULE_NAME_ROOT . '_';
        $this->name             = $this->rootName . $this->customName;
        $this->displayName      = 'MXB banner: ' . $this->customName;
        $this->customClass      = 'banner img-responsive';
        $this->templateFile     = 'module:' . $this->name . '/mxb_banner.tpl';
        $this->version          = '1.0.3';
        $this->dev_version      = self::MXB_DEV_VERSION;
        $this->author           = 'PrestaShop - customized by MXB Informatica';
        $this->need_instance    = 0;
        $this->bootstrap        = true;
        $this->description      = $this->l('Displays a banner on your shop in hook') . ': ' . $this->mainHook . '.' . $this->l('You can always move this module to another hook if you like.');
        $this->ps_versions_compliancy = array('min' => '1.7.1.0', 'max' => _PS_VERSION_);

        // not used ...
        $this->disableMobileDevice  = false;
        $this->registerModuleJs     = true;    

        parent::__construct();

        // configuration values names
        $this->banner_img   = $this->name . '_IMG';
        $this->banner_link  = $this->name . '_LINK';
        $this->banner_desc  = $this->name . '_DESC';
        $this->banner_type  = $this->name . '_TYPE';
        $this->banner_html  = $this->name . '_HTML';
        $this->banner_max_width = $this->name . '_MAX_WIDTH';

        // TODO: REMOVE FOLLOWING ROW IN PRODUCTION: it's only for debug purpuses
        //$this->installModuleFiles();

        $this->checkForUpdates();
    }

    public function install()
    {
        $res = (parent::install() &&
            $this->registerHook($this->mainHook) &&

            /* here were you can hook the banner:
            $this->registerHook('displayHome') &&
            $this->registerHook('displayTop') &&
            $this->registerHook('displayBanner') &&
            
            $this->registerHook('displayLeftColumn') &&
            $this->registerHook('displayRightColumn') &&
            $this->registerHook('displayTopColumn') &&
            $this->registerHook('displayWrapperBottom') &&
            $this->registerHook('displayWrapperTop') &&
            $this->registerHook('displayMaintenance') &&
            
            $this->registerHook('displayInvoice') &&
            $this->registerHook('displayorderConfirmation') &&
            $this->registerHook('displayorderConfirmation2') &&
            $this->registerHook('displayShoppingCart') &&
            $this->registerHook('displayShoppingCartFooter') &&
            $this->registerHook('displayOrderDetail') &&
            $this->registerHook('displayPaymentTop') &&
            
            $this->registerHook('displayNav') &&
            $this->registerHook('displayNav1') &&
            $this->registerHook('displayNav2') &&
            $this->registerHook('displayNavFullWidth') &&
            
            $this->registerHook('displayFooter') &&
            $this->registerHook('displayFooterBefore') &&
            
            $this->registerHook('displayFooterProduct') &&
            $this->registerHook('displayAfterProductThumbs') &&
            $this->registerHook('displayLeftColumnProduct') &&
            $this->registerHook('displayRightColumnProduct') &&
            $this->registerHook('displayProductAdditionalInfo') &&
            $this->registerHook('displayProductExtraContent') &&
            $this->registerHook('displayProductPriceBlock') &&
            */
            $this->registerHook('actionObjectLanguageAddAfter') &&
            $this->installFixtures());

            // if ($this->registerModuleJs)
            $res &= $this->registerHook('actionFrontControllerSetMedia');
            $res &= $this->registerHook('header');

            if ($this->disableMobileDevice) {
                $res &= $this->disableDevice(Context::DEVICE_MOBILE);
            }

            // set module files JS, TPL, CSS
            $this->installModuleFiles();

            return $res;
    }

    public function hookActionObjectLanguageAddAfter($params)
    {
        return $this->installFixture((int)$params['object']->id, Configuration::get($this->banner_img, (int)Configuration::get('PS_LANG_DEFAULT')));
    }

    protected function installFixtures()
    {
        $languages = Language::getLanguages(false);
        if (strpos($this->mainHook, 'displayNav') !== false) {
            $img = 'mxb_banner_contact.jpg';
            $type = 'contact';
        } else {
            $img = 'mxb_banner_normal.jpg';
            $type = 'normal';
        }
        foreach ($languages as $lang) {
            $this->installFixture((int)$lang['id_lang'], $img, $type);
        }

        return true;
    }

    protected function installFixture($id_lang, $image = null, $type = 'normal')
    {
        $values[$this->banner_img][(int)$id_lang] = $image;
        $values[$this->banner_link][(int)$id_lang] = '';
        $values[$this->banner_desc][(int)$id_lang] = '';
        $values[$this->banner_type] = $type;
        $values[$this->banner_html][(int)$id_lang] = '';
        $values[$this->banner_max_width] = '';

        Configuration::updateValue($this->banner_img,  $values[$this->banner_img]);
        Configuration::updateValue($this->banner_link, $values[$this->banner_link]);
        Configuration::updateValue($this->banner_desc, $values[$this->banner_desc]);
        Configuration::updateValue($this->banner_type, $values[$this->banner_type]);
        Configuration::updateValue($this->banner_html, $values[$this->banner_html]);
        Configuration::updateValue($this->banner_max_width, $values[$this->banner_max_width]);
    }

    public function uninstall()
    {
        Configuration::deleteByName($this->banner_img);
        Configuration::deleteByName($this->banner_link);
        Configuration::deleteByName($this->banner_desc);
        Configuration::deleteByName($this->banner_type);
        Configuration::deleteByName($this->banner_html);
        Configuration::deleteByName($this->banner_max_width);
        Configuration::deleteByName($this->name . '_VERSION');

        return parent::uninstall();
    }

    public function postProcess()
    {
        if (Tools::isSubmit('submitStoreConf')) {
            $languages = Language::getLanguages(false);
            $values = array();
            $update_images_values = false;

            foreach ($languages as $lang) {
                if (isset($_FILES[$this->banner_img . '_'.$lang['id_lang']])
                    && isset($_FILES[$this->banner_img . '_'.$lang['id_lang']]['tmp_name'])
                    && !empty($_FILES[$this->banner_img . '_'.$lang['id_lang']]['tmp_name'])) {
                    if ($error = ImageManager::validateUpload($_FILES[$this->banner_img . '_'.$lang['id_lang']], 4000000)) {
                        return $error;
                    } else {
                        $ext = substr($_FILES[$this->banner_img . '_'.$lang['id_lang']]['name'], strrpos($_FILES[$this->banner_img . '_'.$lang['id_lang']]['name'], '.') + 1);
                        $file_name = md5($_FILES[$this->banner_img . '_'.$lang['id_lang']]['name']).'.'.$ext;

                        if (!move_uploaded_file($_FILES[$this->banner_img . '_'.$lang['id_lang']]['tmp_name'], dirname(__FILE__).DIRECTORY_SEPARATOR.'img'.DIRECTORY_SEPARATOR.$file_name)) {
                            return $this->displayError($this->trans('An error occurred while attempting to upload the file.', array(), 'Admin.Notifications.Error'));
                        } else {
                            if (Configuration::hasContext($this->banner_img, $lang['id_lang'], Shop::getContext())
                                && Configuration::get($this->banner_img, $lang['id_lang']) != $file_name) {
                                @unlink(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'img' . DIRECTORY_SEPARATOR . Configuration::get($this->banner_img, $lang['id_lang']));
                            }

                            $values[$this->banner_img][$lang['id_lang']] = $file_name;
                        }
                    }
                    $update_images_values = true;
                }

                $values[$this->banner_link][$lang['id_lang']] = Tools::getValue($this->banner_link . '_'.$lang['id_lang']);
                $values[$this->banner_desc][$lang['id_lang']] = Tools::getValue($this->banner_desc . '_'.$lang['id_lang']);
                $values[$this->banner_html][$lang['id_lang']] = Tools::getValue($this->banner_html . '_'.$lang['id_lang']);
                // $values[$this->banner_html][$lang['id_lang']] = $this->getBannerHtml($lang['id_lang']);
                $values[$this->banner_type] = Tools::getValue($this->banner_type);
                $values[$this->banner_max_width] = Tools::getValue($this->banner_max_width);
            }

            if ($update_images_values) {
                Configuration::updateValue($this->banner_img, $values[$this->banner_img]);
            }

            Configuration::updateValue($this->banner_link, $values[$this->banner_link]);
            Configuration::updateValue($this->banner_desc, $values[$this->banner_desc]);
            Configuration::updateValue($this->banner_type, $values[$this->banner_type]);
            // for html string: Configuration::updateValue($key, $values, $html = true, $id_shop_group = null, $id_shop = null)
            // Configuration::updateValue($this->banner_html, $values[$this->banner_html], true);
            $this->saveBannerHtml($values[$this->banner_html]);
            Configuration::updateValue($this->banner_max_width, $values[$this->banner_max_width]);
            $this->_clearCache($this->templateFile);

            return $this->displayConfirmation($this->trans('The settings have been updated.', array(), 'Admin.Notifications.Success'));
        }

        return '';
    }

    public function getBannerHtml($id_lang = null)
    {
        // $values[$this->banner_html][$lang['id_lang']] = Tools::getValue($this->banner_html . '_'.$lang['id_lang']);

        // read content from file
        $path = _PS_MODULE_DIR_ . $this->name . DIRECTORY_SEPARATOR . 'data' . DIRECTORY_SEPARATOR;
        if (!is_dir($path)) {
            mkdir($path);
            return '';
        }

        $filename = $path . $this->banner_html . (string)$id_lang . '.html';

        if (!file_exists($filename) || !is_readable($filename)) {
            return '';
        }

        $myfile = fopen($filename, "r");
        $fsize = filesize($filename);
        if ($fsize <= 0) {
            return '';
        }
        $content = fread($myfile, filesize($filename));
        fclose($myfile);

        return $content ? $content : '';
    }

    public function saveBannerHtml($contentArray)
    {
        // for html string: Configuration::updateValue($key, $values, $html = true, $id_shop_group = null, $id_shop = null)
        // Configuration::updateValue($this->banner_html, $values[$this->banner_html], true);

        // save content into files (one per lang)
        $path = _PS_MODULE_DIR_ . $this->name . DIRECTORY_SEPARATOR . 'data' . DIRECTORY_SEPARATOR;
        if (!is_dir($path)) {
            mkdir($path);
        }
        
        foreach ($contentArray as $id_lang => $content) {
            $filename = $path . $this->banner_html . (string)$id_lang . '.html';
            $myfile = fopen($filename, "w") or die("Unable to open file " . $filename);
            fwrite($myfile, $content);
            fclose($myfile);
        }
    }

    public function getContent()
    {
        return $this->postProcess().$this->renderForm();
    }

    public function renderForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->trans('Settings', array(), 'Admin.Global'),
                    'icon' => 'icon-cogs'
                ),
                'description' => '<b>' . $this->displayName . ' ver. ' . $this->version . ' (dev. ' . $this->dev_version . ')</b>'
                    . '<br>' . $this->l('Configure a small banner to use as header contact or wide, for your homepage.')
                    . '<br><b>' . $this->l('Documentation') . '</b>: <a href="https://www.mxbinformatica.it/prestashop-mxb-banner/" target="_blank">' . $this->l('click here') . '</a>',

                'input' => array(
                    array(
                        'type' => 'select',
                        'label' => $this->l('Type'),
                        'name' => $this->banner_type,
                        'desc' => $this->l('Select the type. When displayed in displayNav1 / displayNav2 / displayNavFullWidth, a "contact banner" type is also displayed in mobile menu, under the default contact_link.')
                            . '<br>' . $this->l('Substitution of default contact link in header (displayNav1): if you use the module as contact banner, remember to remove the default Contact Info module (ps_contactinfo) from the same hook displayNav1 by the menu "Design > Positions".'),
                        'options' => array(
                            'query' => array(
                                array(
                                    'id' => 'normal',
                                    'name' => $this->l('Normal banner'),
                                ),
                                array(
                                    'id' => 'contact',
                                    'name' => $this->l('Contact banner'),
                                ),
                            ),
                            'id' => 'id',
                            'name' => 'name',
                        ),
                    ),
                    
                    array(
                        'type' => 'text',
                        'lang' => false,
                        'label' => $this->l('Max width'),
                        'name' => $this->banner_max_width,
                        'desc' => $this->l('Enter a max width for the banner. You can enter value in pixel or percentage. For example: "800px" or "80%"')
                            . '<br>' . $this->l('Levae it empty to use a max width of 100%.'),
                    ),
                    array(
                        'type' => 'file_lang',
                        'label' => $this->trans('Banner image', array(), 'Modules.Banner.Admin'),
                        'name' => $this->banner_img,
                        'desc' => $this->l('Upload an image for your top banner. The recommended dimensions are 1110 x 214px if you are using the default theme.')
                            . '<br>' . $this->l('For a "contact banner" use small dimensions like 200 x 50px or similar.'),
                        'lang' => true,
                    ),
                    array(
                        'type' => 'text',
                        'lang' => true,
                        'label' => $this->trans('Banner Link', array(), 'Modules.Banner.Admin'),
                        'name' => $this->banner_link,
                        'desc' => $this->l('Enter the link associated to your banner. When clicking on the banner, the link opens in the same window.')
                            . '<br>' . $this->l('If no link is entered, no action will be taken.'),
                    ),
                    array(
                        'type' => 'text',
                        'lang' => true,
                        'label' => $this->trans('Banner description', array(), 'Modules.Banner.Admin'),
                        'name' => $this->banner_desc,
                        'desc' => $this->l('Please enter a short but meaningful description for the banner.')
                    ),
                    array(
                        'type' => 'textarea',
                        'lang' => true,
                        'label' => $this->l('Html code'),
                        'name' => $this->banner_html,
                        'desc' => $this->l('You can enter html code to display in selected hook.')
                            . '<br>' . $this->l('If you enter some text or html, no image wil be displayed.')

                            . '<br><h2>' . $this->l('How to open an overlay window on banner click') . '</h2>'
                            . '<br><b>' . $this->l('Use html content area to set a content that will be shown on banner or button click') . '</b>'
                            . '<ul><li>' . $this->l('into html area, insert the special tag [overlay] followed by your content, and closed with a second tag [/overlay]. For example:')
                            . '<br><pre><code class="html">' . htmlentities('[overlay]')
                                . '<br>    ' . htmlentities('<iframe src="https://www.mysite.com/newsletter-subscription.html" width="500" height="600" frameborder="0" scrolling="auto" allowfullscreen style="display: block;margin-left: auto;margin-right: auto;max-width: 100%;"></iframe>[/overlay]')
                                . '<br>' . htmlentities('[/overlay]')
                            . '<br></pre></code>'
                            . '<br>' . $this->l('The module will keep your content (a div or an iframe or whatever you need to show on click) and show it into an overlay window.'). '</li>'
                            . '<li>' . $this->l('if you want to use the image as banner, and show the overlay window when a user clicks on it, that is all: just remember to load an image') . '</li>'

                            . '<li>' . $this->l('if you want to show a button, add a second tag [button] with the button text you want to use, and close the tag with [/button]')
                            . '<br><pre><code class="html">'
                                . htmlentities('[button]Newsletter subscription[/button]')
                                . '<br><br>' . htmlentities('[overlay]')
                                . '<br>    ' . htmlentities('<iframe src="https://www.mysite.com/newsletter-subscription.html" width="500" height="600" frameborder="0" scrolling="auto" allowfullscreen style="display: block;margin-left: auto;margin-right: auto;max-width: 100%;"></iframe>[/overlay]')
                                . '<br>' . htmlentities('[/overlay]')
                            . '<br></pre></code>'
                            . '</li>'
                            . '<li>' . $this->l('if no image and no [button] tag was set, the descriprion will be shown and used as clickable area.') . '</li>'
                            . '<ul>',
                    ),
                ),
                'submit' => array(
                    'title' => $this->trans('Save', array(), 'Admin.Actions')
                )
            ),
        );

        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->default_form_language = $lang->id;
        $helper->module = $this;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitStoreConf';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'uri' => $this->getPathUri(),
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );

        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues()
    {
        $languages = Language::getLanguages(false);
        $fields = array();

        $fields[$this->banner_type] = Tools::getValue($this->banner_type, Configuration::get($this->banner_type));
        $fields[$this->banner_max_width] = Tools::getValue($this->banner_max_width, Configuration::get($this->banner_max_width));

        foreach ($languages as $lang) {
            $fields[$this->banner_img][$lang['id_lang']] = Tools::getValue($this->banner_img . '_'.$lang['id_lang'], Configuration::get($this->banner_img, $lang['id_lang']));
            $fields[$this->banner_link][$lang['id_lang']] = Tools::getValue($this->banner_link . '_'.$lang['id_lang'], Configuration::get($this->banner_link, $lang['id_lang']));
            $fields[$this->banner_desc][$lang['id_lang']] = Tools::getValue($this->banner_desc . '_'.$lang['id_lang'], Configuration::get($this->banner_desc, $lang['id_lang']));
            // $fields[$this->banner_html][$lang['id_lang']] = Tools::getValue($this->banner_html . '_'.$lang['id_lang'], Configuration::get($this->banner_html, $lang['id_lang']));
            $fields[$this->banner_html][$lang['id_lang']] = $this->getBannerHtml($lang['id_lang']);
        }

        return $fields;
    }

    public function renderWidget($hookName, array $params)
    {
        if (!$this->isCached($this->templateFile, $this->getCacheId($this->name))) {
            $this->smarty->assign($this->getWidgetVariables($hookName, $params));
        }

        return $this->fetch($this->templateFile, $this->getCacheId($this->name));
    }

    public function getWidgetVariables($hookName, array $params)
    {
        $imgname = Configuration::get($this->banner_img, $this->context->language->id);

        if ($imgname && file_exists(_PS_MODULE_DIR_.$this->name.DIRECTORY_SEPARATOR.'img'.DIRECTORY_SEPARATOR.$imgname)) {
            $this->smarty->assign('banner_img', $this->context->link->protocol_content . Tools::getMediaServer($imgname) . $this->_path . 'img/' . $imgname);
        }

        $banner_link = Configuration::get($this->banner_link, $this->context->language->id);
        if (!$banner_link) {
            $banner_link = $this->context->link->getPageLink('index');
        }


        // $banner_html = Configuration::get($this->banner_html, $this->context->language->id);
        $banner_html = $this->getBannerHtml($this->context->language->id);
        if (strlen($banner_html) > 0) {
            if (strpos($banner_html, '[overlay') !== false) {
                // recover overlay content and set variables
                /*
                    content sample:
                        [overlay]
                        ... html content ...
                        [/overlay]
                    this way the image banner will be used as button to trigger the overlay window
    
                */
                $overlay_content = substr($banner_html, strpos($banner_html, '[overlay]') + strlen('[overlay]'));
                $overlay_content = substr($overlay_content, 0, strpos($overlay_content, '[/overlay]'));
                // str_replace('[overlay]', '', $banner_html
                $this->smarty->assign('overlay_content', $overlay_content);

                if (strpos($banner_html, '[button') !== false) {
                    $overlay_button = substr($banner_html, strpos($banner_html, '[button]') + strlen('[button]'));
                    $overlay_button = substr($overlay_button, 0, strpos($overlay_button, '[/button]'));
                    $this->smarty->assign('overlay_button', $overlay_button);
                }
            } else {
                $this->smarty->assign('banner_html', $banner_html);
            }
        }

        // assign class to hide the banner in xs dev (mobile)
        // only when it is a "contact" type and is in certain hooks in the header.
        $banner_hidden_class = '';
        $banner_type = Configuration::get($this->banner_type);
        if ($banner_type == 'contact'
            && ($hookName == 'displayNav1'
            || $hookName == 'displayNav2'
            || $hookName == 'displayNavFullWidth')
        ) {
            $banner_hidden_class = 'hidden-sm-down';
        } 
        $banner_max_width = Configuration::get($this->banner_max_width);
        //LogDebug::WriteLog('Mxb_Banner_Contact', 'getWidgetVariables', 'banner_hidden_class='.$banner_hidden_class.', hookName='.$hookName.', banner_type='.$banner_type, true);

        return array(
            'banner_link' => $this->updateUrl($banner_link),
            'banner_desc' => Configuration::get($this->banner_desc, $this->context->language->id),
            'banner_class' => $this->customClass,
            'banner_hidden_class' => $banner_hidden_class,
            'banner_type' => $banner_type,
            'banner_max_width' => $banner_max_width,
            'banner_name' => $this->name,
            'hookName' => $hookName,
        );
    }

    private function updateUrl($link)
    {
        if (substr($link, 0, 7) !== "http://" && substr($link, 0, 8) !== "https://") {
            $link = "http://" . $link;
        }

        return $link;
    }

     /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookHeader()
    {
        $this->context->controller->addJquery();
        $this->context->controller->addJS($this->_path.'/views/js/front.js');
        $this->context->controller->addJS($this->_path.'/views/js/module.js');
        $this->context->controller->addCSS($this->_path.'/views/css/front.css');
    }

    public function installModuleFiles()
    {
        $ret = $this->installModuleFile('translations/it.php');
        $ret &= $this->installModuleFile('views/css/front.css');
        $ret &= $this->installModuleFile('views/js/module.js');
        return $ret;
    }

    public function installModuleFile($module_file = 'translations/it.php', $overwrite = true)
    {
        $filedir = _PS_MODULE_DIR_.$this->name.DIRECTORY_SEPARATOR;
        $filename_src = $filedir . $module_file . '_'; // add underscore to open the source unmodifyed file
        $filename_tgt = $filedir . $module_file;
        $searchString = '_' . $this->rootName;
        
        if (!file_exists($filename_src)) {
            return false;
        }
        if (file_exists($filename_tgt) && !$overwrite) {
            return false;
        }
        
        $myfile = fopen($filename_src, "r");
        $filesize = filesize($filename_src);
        if ((int)$filesize === 0) {
            return false;
        }
        $content = fread($myfile, $filesize);
        fclose($myfile);

        // change default class with custom class and save file
        // text to replace not found ?
        //if (strpos($content, $searchString) === false)
        //    return true;
        // already replaced (replace text is already present) ?
        if (strpos($content, $this->name) === false) {
            $content = str_replace($searchString, $this->name, $content); 
        }

        // update the real file
        $myfile = fopen($filename_tgt, "w");
        fwrite($myfile, $content);
        fclose($myfile);

        return true;
    }

    protected function checkForUpdates()
    {
        // check for back-office
        //if (!Tools::getIsset('controller'))
        //    return false;
        $version = (int)Configuration::getGlobalValue($this->name . '_VERSION');
        if ($version === 0) {
            // module was fresh of installation: no updates are needed: update current version and exit
            Configuration::updateGlobalValue($this->name . '_VERSION', self::MXB_DEV_VERSION);
            if ((int)self::MXB_DEV_VERSION <= 1) {
                return false;
            }
        }
        if ((int)self::MXB_DEV_VERSION <= (int)$version) {
            return false;
        }

        $confirmations = array();
        $errors = array();

        for ($i = $version+1; $i <= self::MXB_DEV_VERSION; $i++) {
            $version = $i;
            switch ($version) {
                case 1:
                    break;
                case 2:
                    // $this->installModuleFile('views/js/front.js');
                    $this->installModuleFile('views/css/front.css');
                    break;
            }
        }
        // update current version
        Configuration::updateGlobalValue($this->name . '_VERSION', $version);
        return true;
    }
}

